@@ -42,13 +42,13 @@ import (
 	operatorclientv1 "github.com/openshift/client-go/operator/clientset/versioned/typed/operator/v1"
 
 	// operator
-
+	"github.com/openshift/console-operator/pkg/console/metrics"
+	statushelpers "github.com/openshift/console-operator/pkg/console/status"
 	"github.com/openshift/console-operator/pkg/console/subresource/configmap"
 	"github.com/openshift/console-operator/pkg/console/subresource/deployment"
 	"github.com/openshift/console-operator/pkg/console/subresource/oauthclient"
 	"github.com/openshift/console-operator/pkg/console/subresource/route"
 	"github.com/openshift/console-operator/pkg/console/subresource/secret"
-	"github.com/openshift/console-operator/pkg/console/subresource/service"
 )
 
 const (
@@ -70,31 +70,38 @@ type consoleOperator struct {
 	routeClient   routeclientv1.RoutesGetter
 	oauthClient   oauthclientv1.OAuthClientsGetter
 	versionGetter status.VersionGetter
+	// metrics
+	consoleMetrics *metrics.ConsoleMetrics
 	// recorder
 	recorder       events.Recorder
 	resourceSyncer resourcesynccontroller.ResourceSyncer
 }
 
 func NewConsoleOperator(
-	// informers
-	operatorConfigInformer operatorinformerv1.ConsoleInformer,
-	configInformer configinformer.SharedInformerFactory,
-
-	coreV1 corev1.Interface,
-	managedCoreV1 corev1.Interface,
-	deployments appsinformersv1.DeploymentInformer,
-	routes routesinformersv1.RouteInformer,
-	oauthClients oauthinformersv1.OAuthClientInformer,
-
-	// clients
-	operatorConfigClient operatorclientv1.OperatorV1Interface,
+	// top level config
 	configClient configclientv1.ConfigV1Interface,
+	configInformer configinformer.SharedInformerFactory,
+	// operator
+	operatorConfigClient operatorclientv1.OperatorV1Interface,
+	operatorConfigInformer operatorinformerv1.ConsoleInformer,
+	// core resources
 	corev1Client coreclientv1.CoreV1Interface,
+	coreV1 corev1.Interface,
+	// deployments
 	deploymentClient appsv1.DeploymentsGetter,
+	deployments appsinformersv1.DeploymentInformer,
+	// routes
 	routev1Client routeclientv1.RoutesGetter,
+	routes routesinformersv1.RouteInformer,
+	// oauth
 	oauthv1Client oauthclientv1.OAuthClientsGetter,
+	oauthClients oauthinformersv1.OAuthClientInformer,
+	// openshift managed
+	managedCoreV1 corev1.Interface,
+	// metrics
+	consoleMetrics *metrics.ConsoleMetrics,
+	// event handling
 	versionGetter status.VersionGetter,
-	// recorder
 	recorder events.Recorder,
 	resourceSyncer resourcesynccontroller.ResourceSyncer,
 ) operator.Runner {
@@ -114,6 +121,8 @@ func NewConsoleOperator(
 		routeClient:   routev1Client,
 		oauthClient:   oauthv1Client,
 		versionGetter: versionGetter,
+		// metrics
+		consoleMetrics: consoleMetrics,
 		// recorder
 		recorder:       recorder,
 		resourceSyncer: resourceSyncer,
@@ -182,10 +191,8 @@ func (c *consoleOperator) Sync(obj metav1.Object) error {
 
 	proxyConfig, err := c.proxyConfigClient.Get(api.ConfigResourceName, metav1.GetOptions{})
 	if err != nil {
-		if !errors.IsNotFound(err) {
-			return err
-		}
-		proxyConfig = nil
+		klog.Errorf("proxy config error: %v", err)
+		return err
 	}
 
 	configs := configSet{
@@ -212,18 +219,18 @@ func (c *consoleOperator) handleSync(configs configSet) error {
 	case operatorsv1.Unmanaged:
 		klog.V(4).Infoln("console is in an unmanaged state.")
 		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			c.SyncStatus(updatedStatus)
+			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
 		}
 		return nil
 	case operatorsv1.Removed:
 		klog.V(4).Infoln("console has been removed.")
 		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			c.SyncStatus(updatedStatus)
+			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
 		}
-		return c.removeConsole(updatedStatus)
+		return c.removeConsole()
 	default:
 		if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-			c.SyncStatus(updatedStatus)
+			statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
 		}
 		return fmt.Errorf("console is in an unknown state: %v", updatedStatus.Spec.ManagementState)
 	}
@@ -233,18 +240,16 @@ func (c *consoleOperator) handleSync(configs configSet) error {
 	// finally write out the set of conditions currently set if anything has changed
 	// to avoid a hot loop
 	if !reflect.DeepEqual(updatedStatus, configs.Operator) {
-		c.SyncStatus(updatedStatus)
+		statushelpers.SyncStatus(c.operatorConfigClient, updatedStatus)
 	}
 	return err
 }
 
 // this may need to move to sync_v400 if versions ever have custom delete logic
-func (c *consoleOperator) removeConsole(cr *operatorsv1.Console) error {
+func (c *consoleOperator) removeConsole() error {
 	klog.V(2).Info("deleting console resources")
 	defer klog.V(2).Info("finished deleting console resources")
 	var errs []error
-	// service
-	errs = append(errs, c.serviceClient.Services(api.TargetNamespace).Delete(service.Stub().Name, &metav1.DeleteOptions{}))
 	// route
 	errs = append(errs, c.routeClient.Routes(api.TargetNamespace).Delete(route.Stub().Name, &metav1.DeleteOptions{}))
 	// configmaps
